@@ -310,7 +310,7 @@ create_table_pdf <- function(rs, ts, pi, content_blank_row, wrap_flag,
   bdy <- get_table_body_pdf(rs, pi$data, pi$col_width, 
                             pi$col_align, pi$table_align, ts$borders,
                             ystart = ys,
-                            spwidths)
+                            spwidths, frb = ts$first_row_blank)
   ys <- ys + bdy$points
 
 
@@ -607,7 +607,7 @@ get_table_header_pdf <- function(rs, ts, widths, lbls, halgns, talgn,
       pnts <- pnts + 3
     }
   } else {
-    tbs <- ystart - rh
+    tbs <- ystart - rh + 1
     pnts <- pnts + bh
   }
 
@@ -670,7 +670,7 @@ get_table_header_pdf <- function(rs, ts, widths, lbls, halgns, talgn,
   }
   
   # Top border
-  if (any(brdrs %in% c("all", "outside", "top")) & !has_spans) {
+  if ((any(brdrs == "all")) | (any(brdrs %in% c("outside", "top")) & !has_spans)) {
     
     ret[[length(ret) + 1]] <- page_hline(tlb * conv, 
                                          tbs, 
@@ -797,7 +797,12 @@ get_spanning_header_pdf <- function(rs, ts, pi, ystart = 0, brdr_flag = FALSE) {
   }
   
   ret <- list()
+  
   lline <- ystart
+  if (brdr_flag) {
+    lline <- ystart + bs
+  } 
+  
   
   # Open device context
   pdf(NULL)
@@ -822,54 +827,7 @@ get_spanning_header_pdf <- function(rs, ts, pi, ystart = 0, brdr_flag = FALSE) {
     cnt[length(cnt) + 1] <- 1 
   
     
-    # Loop for cell definitions
- #   for(j in seq_along(widths)) {
-      
-      # Get cell borders
-      # b <- get_cell_borders(length(wlvl) - l + 1, j, 10, nrow(s), brdrs)
-      
-      # Add colspans
-  #    vl <- lbls[j]
-      
-      # Special handling of borders for different situations.  
-      # I hate this, but can't see a way around it.
-      # if (any(brdrs %in% c("all", "inside"))) {
-      #   sflg <- "B"
-      #   if (j > 1) {
-      #     if (cs[j] > 1)
-      #       sflg <- ""
-      #   }
-      #   
-      #   if (vl == "") {
-      #     bb <- get_cell_borders(length(lvls) - l + 1, j, length(lvls), 
-      #                            length(sz), brdrs, 
-      #                            flag = sflg)
-      #   } else 
-      #     bb <- b
-      # } else if (all(brdrs == "outside")) {
-      #   
-      #   if (vl == "")
-      #     bb <- b
-      #   else 
-      #     bb <- paste0(b, "\\clbrdrb\\brdrs")
-      #   
-      # } else {
-      #   
-      #   if (vl == "") {
-      #     bb <- get_cell_borders(length(lvls) - l + 1, j, length(lvls), 
-      #                            length(sz), brdrs, 
-      #                            flag = "")
-      #   } else 
-      #     bb <- paste0(b, "\\clbrdrb\\brdrs")
-      #   
-      # }
-      
-      # Don't forget about underline parameter
-      # if (s$span[j] > 0 & s$underline[j])
-      #   r <- paste0(r, "\\clvertalb", bb, "\\clbrdrb\\brdrs\\cellx", sz[j])
-      # else 
-      #   r <- paste0(r, "\\clvertalb", bb, "\\cellx", sz[j])
-  #  }
+
     
    mxyl <- 0
    mxlns <- 0
@@ -911,6 +869,10 @@ get_spanning_header_pdf <- function(rs, ts, pi, ystart = 0, brdr_flag = FALSE) {
           if (ln == 1)
             yline <- yline + ((mxlns - tmp$lines) * rh)
           
+          adj <- 0
+          if (any(brdrs %in% c("all", "inside")))
+              adj <- 4
+          
           # Get pdf text for label
           ret[[length(ret) + 1]] <- page_text(tmp$text[ln], rs$font_size, 
                                               bold = FALSE,
@@ -919,7 +881,7 @@ get_spanning_header_pdf <- function(rs, ts, pi, ystart = 0, brdr_flag = FALSE) {
                                                                 tmp$widths[ln],
                                                                 units = rs$units,
                                                                 align = algns[k]),
-                                              ypos = yline - 2)
+                                              ypos = yline - adj)
           yline <- yline + rh
           if (yline > mxyl)
             mxyl <- yline
@@ -981,10 +943,12 @@ get_spanning_header_pdf <- function(rs, ts, pi, ystart = 0, brdr_flag = FALSE) {
   if (length(lvls) > 0) {
 
     
+    ypos <- ystart - rh + bs 
+    
     if (any(brdrs %in% c("all", "outside", "top"))) {
       
       ret[[length(ret) + 1]] <- page_hline(tlb * conv,
-                                           ystart - rh,
+                                           ypos,
                                            (trb - tlb) * conv)
       
     }
@@ -1001,7 +965,7 @@ get_spanning_header_pdf <- function(rs, ts, pi, ystart = 0, brdr_flag = FALSE) {
       
       
       ret[[length(ret) + 1]] <- page_vline(tlb * conv, 
-                                           ystart - rh , 
+                                           ypos, 
                                            (cnts * rh)) 
       
     }
@@ -1010,7 +974,7 @@ get_spanning_header_pdf <- function(rs, ts, pi, ystart = 0, brdr_flag = FALSE) {
       
       
       ret[[length(ret) + 1]] <- page_vline(trb * conv, 
-                                           ystart - rh, 
+                                           ypos, 
                                            (cnts * rh)) 
       
     }
@@ -1030,7 +994,7 @@ get_spanning_header_pdf <- function(rs, ts, pi, ystart = 0, brdr_flag = FALSE) {
 #' @noRd
 get_table_body_pdf <- function(rs, tbl, widths, algns, talgn, tbrdrs, 
                                ystart = 0, spwidths = list(), 
-                               brdr_flag = FALSE) {
+                               brdr_flag = FALSE, frb = FALSE) {
   
   border_flag <- FALSE
   
@@ -1093,7 +1057,7 @@ get_table_body_pdf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
     trb <- width
   }
   
-  rline <- ystart 
+  rline <- ystart + 1
   
   ret <- c()
   
@@ -1157,20 +1121,59 @@ get_table_body_pdf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
       
       yline <- rline
       
+    }
+    
+
+    # Loop for columns 
+    for(j in nms) {
+      
       # Applies inside vertical borders
       if (any(brdrs %in% c("all", "inside")) & j != nms[length(nms)] 
           & !blnks[i] %in% c("B", "L")) {
         
-        ret[[length(ret) + 1]] <- page_vline(rb * conv, (rline + bs) - rh, rh)
+        if (j == nms[1]) {
+          lb <- tlb
+          rb <- lb + wdths[j]
+        } else {
+          lb <- rb
+          rb <- lb + wdths[j]
+        }
+        
+        if (i == 1) { 
+          
+          if (is.null(frb)) {
+            ret[[length(ret) + 1]] <- page_vline(rb * conv, (rline + bs) - rh - 1, 
+                                               mxrw - rline + 1)
+           } else if (frb == FALSE) {
+            ret[[length(ret) + 1]] <- page_vline(rb * conv, (rline + bs) - rh - 1, 
+                                               mxrw - rline + 1)
+           } else {
+             ret[[length(ret) + 1]] <- page_vline(rb * conv, (rline + bs) - rh, 
+                                                  mxrw - rline + 1)
+           }
+          
+        } else if (i == nrow(t)) {
+          
+          ret[[length(ret) + 1]] <- page_vline(rb * conv, (rline + bs) - rh, 
+                                               mxrw - rline + 1)
+        
+        } else {
+          
+          ret[[length(ret) + 1]] <- page_vline(rb * conv, (rline + bs) - rh, 
+                                               mxrw - rline )
+          
+        }
         
       }
-
+      
     }
+
+    
     
     # Applies inside horizontal borders
     if (any(brdrs %in% c("all", "inside")) & i < nrow(t)) {
     
-      ret[[length(ret) + 1]] <- page_hline(tlb * conv, rline + bs, 
+      ret[[length(ret) + 1]] <- page_hline(tlb * conv, mxrw -rh + bs, 
                                            (trb - tlb) * conv)
     
     }
@@ -1180,7 +1183,7 @@ get_table_body_pdf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
   }
   
 
-  ypos <- ystart - rs$row_height + bh
+  ypos <- ystart - rs$row_height + bh - 1
   
   
   #ylen <- cnt * rh
@@ -1188,11 +1191,11 @@ get_table_body_pdf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
   
   if (any(brdrs %in% c("all", "left", "outside"))) {
     
-    ret[[length(ret) + 1]] <- page_vline(tlb * conv, ypos, ylen)
+    ret[[length(ret) + 1]] <- page_vline(tlb * conv, ypos, ylen - ypos)
   }
   if (any(brdrs %in% c("all", "right", "outside"))) {
     
-    ret[[length(ret) + 1]] <- page_vline(trb * conv, ypos, ylen)
+    ret[[length(ret) + 1]] <- page_vline(trb * conv, ypos, ylen - ypos)
   }
   
   # pnts <- cnt * rh
@@ -1208,6 +1211,10 @@ get_table_body_pdf <- function(rs, tbl, widths, algns, talgn, tbrdrs,
                                          (trb - tlb) * conv)
     
     border_flag <- TRUE
+    if (any(brdrs %in% c("all"))) {
+      
+      pnts <- pnts - bh 
+    }
    # pnts <- pnts + bh
     
   }
