@@ -26,13 +26,14 @@ test_that("html1: Basic table works as expected.", {
   
   
   fp <- file.path(base_path, "html/test1.html")
+ # print(fp)
   
   dat <- mtcars[1:15, ]
   attr(dat[[2]], "label") <- "Cylin."
   attr(dat[[2]], "width") <- 1
   attr(dat[[2]], "justify") <- "center"
   
-  tbl <- create_table(dat, borders = "outside") %>%
+  tbl <- create_table(dat, borders = "outside", first_row_blank = TRUE) %>%
     titles("Table 1.0", "My Nice Table", borders = c("outside"), 
            width = "content") %>%
     footnotes("My footnote 1", "My footnote 2", borders = "outside", 
